import _extends from "@babel/runtime/helpers/extends";
import React from 'react';
import { bool, func, string } from 'prop-types';
import { useFela } from 'react-fela';
import { makeId, makeIdList, useId } from '../../utils/auto-id';
import { Block } from '../block';
import { Flex } from '../flex';
import { Message } from '../message';
import { Spacer } from '../spacer';
import { Spinner } from '../spinner';
const defaultStyles = _ref => {
  let {
    theme,
    disabled,
    loading,
    isValid
  } = _ref;
  return {
    appearance: 'none',
    borderWidth: 1,
    borderStyle: 'solid',
    borderRadius: 4,
    boxSizing: 'border-box',
    display: 'block',
    width: '100%',
    margin: 0,
    outlineWidth: 0,
    paddingTop: theme.tokens.inputPaddingVertical * 2,
    paddingBottom: theme.tokens.inputPaddingVertical / 2,
    paddingLeft: theme.tokens.inputPaddingHorizontal - 1,
    paddingRight: theme.tokens.inputPaddingHorizontal - 1,
    borderColor: theme.tokens.inputBorder,
    color: theme.tokens.inputForeground,
    background: theme.tokens.inputBackground,
    ...theme.typeScale.columbus.standard.styles,
    '::placeholder': {
      color: 'transparent'
    },
    '&[type="date"][value=""]:not(:focus)': {
      color: 'transparent'
    },
    ':focus': {
      borderColor: theme.tokens.inputBorderFocus,
      '::placeholder': {
        color: theme.tokens.inputPlaceholder
      }
    },
    extend: [{
      condition: loading,
      style: {
        userSelect: 'none'
      }
    }, {
      condition: disabled,
      style: {
        ':disabled': {
          cursor: 'not-allowed',
          borderColor: theme.tokens.inputDisabledBorder,
          backgroundColor: theme.tokens.inputDisabledBackground,
          color: theme.tokens.inputForeground
        }
      }
    }, {
      condition: !isValid,
      style: {
        ':not(:focus)': {
          borderWidth: 2,
          borderColor: theme.color.foreground.alert,
          paddingTop: theme.tokens.inputPaddingVertical * 2 - 1,
          paddingBottom: theme.tokens.inputPaddingVertical / 2 - 1,
          paddingLeft: theme.tokens.inputPaddingHorizontal - 2,
          paddingRight: theme.tokens.inputPaddingHorizontal - 2
        }
      }
    }]
  };
};
const labelStyle = _ref2 => {
  let {
    isEmpty,
    isValid,
    theme
  } = _ref2;
  return {
    paddingLeft: theme.tokens.inputPaddingHorizontal,
    paddingRight: theme.tokens.inputPaddingHorizontal,
    color: isValid ? theme.color.foreground.secondary : theme.color.foreground.alert,
    transitionProperty: 'font-size, transform',
    transitionDuration: '60ms',
    transitionTimingFunction: 'ease-out',
    transform: 'translateY(' + (isEmpty ? 17 : 8) + 'px)',
    fontSize: isEmpty ? 16 : 12,
    letterSpacing: '0.02em',
    fontFamily: theme.fontTypes.NOVUM,
    fontWeight: 300,
    position: 'absolute',
    pointerEvents: 'none',
    top: 0
  };
};

/**
 * @deprecated Use `import { TextInput } from '@volvo-cars/react-forms'` instead. See [TextInput](https://developer.volvocars.com/design-system/web/?path=/docs/components-forms-input-textinput--docs)
 */
export const TextInput = /*#__PURE__*/React.forwardRef((_ref3, ref) => {
  let {
    onChange,
    type,
    value = '',
    isValid = true,
    label = '',
    description = '',
    errorMessage = '',
    loading = false,
    disabled = false,
    ...props
  } = _ref3;
  const {
    theme
  } = useFela();
  const isEmpty = (value || '').length === 0;
  const styleProps = {
    isEmpty,
    isValid,
    disabled,
    loading,
    theme
  };
  const id = useId('vcc-ui-text-input', props.id);
  const errorMessageId = makeId(id, 'error');
  const descriptionId = makeId(id, 'description');
  const describedBy = makeIdList([errorMessage && errorMessageId, description && descriptionId]);
  const messages = /*#__PURE__*/React.createElement(React.Fragment, null, errorMessage || description ? /*#__PURE__*/React.createElement(Spacer, {
    size: 0.5
  }) : null, errorMessage ? /*#__PURE__*/React.createElement(Message, {
    type: "error",
    id: errorMessageId
  }, errorMessage) : null, description ? /*#__PURE__*/React.createElement(Message, {
    id: descriptionId
  }, description) : null);
  return /*#__PURE__*/React.createElement(Flex, {
    extend: {
      flexDirection: 'column',
      width: '100%',
      ':focus-within label': {
        transform: 'translateY(8px)',
        fontSize: 12
      }
    }
  }, /*#__PURE__*/React.createElement(Flex, {
    extend: {
      position: 'relative'
    }
  }, loading && /*#__PURE__*/React.createElement(Flex, {
    extend: {
      position: 'absolute',
      width: '100%',
      height: '100%',
      alignItems: 'center',
      justifyContent: 'center'
    }
  }, /*#__PURE__*/React.createElement(Spinner, {
    color: theme.tokens.inputForeground,
    size: 24
  })), !loading ? /*#__PURE__*/React.createElement(Block, {
    as: "label",
    htmlFor: id,
    extend: labelStyle(styleProps)
  }, label) : null, /*#__PURE__*/React.createElement(Block, _extends({}, props, {
    ref: ref,
    as: "input",
    value: loading ? '' : value,
    disabled: disabled || loading,
    type: type,
    id: id,
    onChange: onChange,
    extend: defaultStyles(styleProps)
  }, describedBy && {
    'aria-describedby': describedBy
  }))), messages);
});
TextInput.displayName = 'TextInput';
TextInput.propTypes = {
  type: string,
  id: string,
  name: string,
  /** Renders a label inside the input. */
  label: string.isRequired,
  /** Renders a description text underneath the input. */
  description: string,
  /** Renders a red error message for validation underneath the input. */
  errorMessage: string,
  /** onChange handler. Triggers on every keyboard and generally
   * is here where you change the value of the `value` property. */
  onChange: func.isRequired,
  /**
   * Value of the textInput. This should be stored in the
   * state of the parent component.
   */
  value: string.isRequired,
  /** Renders the input as valid or invalid. */
  isValid: bool,
  loading: bool,
  disabled: bool
};