"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.responsiveProps = void 0;
exports.styleRenderer = styleRenderer;
var _cssInJsUtils = require("css-in-js-utils");
var _fela = require("fela");
var _felaEnforceLonghands = _interopRequireDefault(require("fela-enforce-longhands"));
var _felaPluginEmbedded = _interopRequireDefault(require("fela-plugin-embedded"));
var _felaPluginExtend = _interopRequireDefault(require("fela-plugin-extend"));
var _felaPluginFallbackValue = _interopRequireDefault(require("fela-plugin-fallback-value"));
var _felaPluginHoverMedia = _interopRequireDefault(require("fela-plugin-hover-media"));
var _felaPluginNamedKeys = _interopRequireDefault(require("fela-plugin-named-keys"));
var _felaPluginPrefixer = _interopRequireDefault(require("fela-plugin-prefixer"));
var _felaPluginResponsiveValue = _interopRequireDefault(require("fela-plugin-responsive-value"));
var _felaPluginRtl = _interopRequireDefault(require("fela-plugin-rtl"));
var _felaPluginThemeValue = _interopRequireDefault(require("fela-plugin-theme-value"));
var _felaPluginUnit = _interopRequireDefault(require("fela-plugin-unit"));
var _felaSortClassnames = _interopRequireDefault(require("fela-sort-classnames"));
var _felaSortMediaQueryMobileFirst = _interopRequireDefault(require("fela-sort-media-query-mobile-first"));
var _felaTools = require("fela-tools");
// whitelisting all the props that support responsive array values
const responsiveProps = exports.responsiveProps = {
  alignContent: true,
  alignItems: true,
  alignSelf: true,
  aspectRatio: true,
  columnGap: true,
  display: true,
  flex: true,
  flexBasis: true,
  flexDirection: true,
  flexGrow: true,
  flexShrink: true,
  flexWrap: true,
  gap: true,
  height: true,
  justifyContent: true,
  margin: true,
  marginBottom: true,
  marginLeft: true,
  marginRight: true,
  marginTop: true,
  maxHeight: true,
  maxWidth: true,
  minHeight: true,
  minWidth: true,
  order: true,
  padding: true,
  paddingBottom: true,
  paddingLeft: true,
  paddingRight: true,
  paddingTop: true,
  rowGap: true,
  textAlign: true,
  width: true
};
const getResponsiveMediaQueries = (values, props) => {
  const {
    fromM,
    fromL,
    fromXL
  } = props.theme.breakpoints;
  const mediaQueryMap = {
    2: [fromM],
    3: [fromM, fromL],
    4: [fromM, fromL, fromXL]
  };
  return mediaQueryMap[values.length];
};
function styleRenderer() {
  let {
    isRtl,
    enforceLonghands = true,
    wrapHoverWithMediaHover = false,
    renderFonts = true,
    ...rest
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  const options = rest || {};
  // eslint-disable-next-line testing-library/render-result-naming-convention
  const renderer = (0, _fela.createRenderer)({
    ...options,
    enhancers: [(0, _felaSortClassnames.default)(), (0, _felaSortMediaQueryMobileFirst.default)(), ...(enforceLonghands ? [(0, _felaEnforceLonghands.default)()] : []), ...(options.enhancers || [])],
    plugins: [responsiveObjectValue(responsiveProps), (0, _felaPluginExtend.default)(), (0, _felaPluginEmbedded.default)(), (0, _felaPluginResponsiveValue.default)(getResponsiveMediaQueries, responsiveProps), (0, _felaPluginNamedKeys.default)(props => props && props.theme && props.theme.breakpoints || {}), renderFonts && themeFontsPlugin, (0, _felaPluginRtl.default)(isRtl ? 'rtl' : 'ltr'), (0, _felaPluginThemeValue.default)({
      color: theme => theme.color,
      backgroundColor: theme => theme.color,
      borderColor: theme => theme.color,
      stroke: theme => theme.color,
      fill: theme => theme.color,
      '--icon-color': theme => theme.color,
      '--icon-color-secondary': theme => theme.color
    }), ...(options.plugins || []), (0, _felaPluginUnit.default)(), (0, _felaPluginFallbackValue.default)(), (0, _felaPluginPrefixer.default)(), wrapHoverWithMediaHover && (0, _felaPluginHoverMedia.default)()].filter(Boolean)
  });
  return renderer;
}

// TODO: move to fela repo as an official plugin
function themeFontsPlugin(style, type, renderer, props) {
  const fonts = props.theme && props.theme.fonts || [];
  const fontsPath = props.theme && props.theme.fontsPath || '';
  for (const property in style) {
    const value = style[property];

    // TODO: maybe we wanna cache already rendered fonts
    // but no high prio as Fela does that as well
    if (typeof value === 'string' && property === 'fontFamily') {
      // check each alternative font value
      const fontValues = value.split(',');
      const usedFonts = fonts.filter(font => fontValues.indexOf(font.fontFamily) !== -1);
      if (usedFonts.length > 0) {
        usedFonts.forEach(_ref => {
          let {
            fontFamily,
            src,
            ...fontProps
          } = _ref;
          return renderer.renderFont(fontFamily, src.map(
          // allow absolute files with http prefix
          file => (file.indexOf('http') === -1 ? fontsPath : '') + file), fontProps);
        });
      }
    } else if (typeof value === 'object' && !Array.isArray(value)) {
      themeFontsPlugin(value, type, renderer, props);
    }
  }
  return style;
}

// TODO: move to fela repo as an official plugin
function resolveResponsiveObjectValues(style, properties) {
  for (const property in style) {
    if (properties[property]) {
      const value = style[property];
      if (typeof value === 'object' && !Array.isArray(value)) {
        const {
          default: defaultValue,
          ...mediaValues
        } = value;
        (0, _cssInJsUtils.assignStyle)(style, {
          [property]: defaultValue
        }, {
          extend: [(0, _felaTools.mapValueToMediaQuery)(mediaValues, value => ({
            [property]: value
          }))]
        });
      }
    }
  }
  return style;
}
function responsiveObjectValue() {
  let properties = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return style => resolveResponsiveObjectValues(style, properties);
}