import { CurrentTheme } from '../types/shared';
export declare function getFontTypes(locale?: string): {
    BROAD: string;
    NOVUM: string;
    SERIF: string;
};
export declare const FONT_WEIGHTS: {
    semiLight: number;
    regular: number;
    medium: number;
    bold: number;
};
export declare function getTypeScale(color: CurrentTheme['color'], locale?: string): {
    /**
      Headings
    */
    peary: {
        standard: {
            element: string;
            styles: {
                fromM: {
                    fontSize: string;
                    lineHeight: number;
                };
                fromL: {
                    fontSize: string;
                    lineHeight: number;
                };
                fontFeatureSettings: string;
                fontFamily: string;
                fontSize: string;
                fontWeight: number;
                lineHeight: number;
            } | {
                fromM: {
                    fontSize: string;
                    lineHeight: number;
                };
                fromL: {
                    fontSize: string;
                    lineHeight: number;
                };
                fontFeatureSettings?: undefined;
                fontFamily: string;
                fontSize: string;
                fontWeight: number;
                lineHeight: number;
            };
        };
    };
    cook: {
        standard: {
            element: string;
            styles: {
                fromM: {
                    fontSize: string;
                    lineHeight: number;
                };
                fromL: {
                    fontSize: string;
                    lineHeight: number;
                };
                fontFeatureSettings: string;
                fontFamily: string;
                fontSize: string;
                fontWeight: number;
                lineHeight: number;
            } | {
                fromM: {
                    fontSize: string;
                    lineHeight: number;
                };
                fromL: {
                    fontSize: string;
                    lineHeight: number;
                };
                fontFeatureSettings?: undefined;
                fontFamily: string;
                fontSize: string;
                fontWeight: number;
                lineHeight: number;
            };
        };
    };
    ootah: {
        standard: {
            element: string;
            styles: {
                fromM: {
                    fontSize: string;
                    lineHeight: number;
                };
                fromL: {
                    fontSize: string;
                    lineHeight: number;
                };
                fontFeatureSettings: string;
                fontFamily: string;
                fontSize: string;
                fontWeight: number;
                lineHeight: number;
            } | {
                fromM: {
                    fontSize: string;
                    lineHeight: number;
                };
                fromL: {
                    fontSize: string;
                    lineHeight: number;
                };
                fontFeatureSettings?: undefined;
                fontFamily: string;
                fontSize: string;
                fontWeight: number;
                lineHeight: number;
            };
        };
        emphasis: {
            styles: {
                fontStyle: string;
                fontWeight: number;
            };
        };
    };
    /**
      Sub-Headings
    */
    hillary: {
        standard: {
            element: string;
            styles: {
                fontFeatureSettings: string;
                fontFamily: string;
                fontSize: string;
                fontWeight: number;
                lineHeight: number;
            } | {
                fontFeatureSettings?: undefined;
                fontFamily: string;
                fontSize: string;
                fontWeight: number;
                lineHeight: number;
            };
        };
        'inline-link': {
            element: string;
            styles: {
                color: string;
                display: string;
                '[href]': {
                    textDecoration: string;
                };
                '&:hover': {
                    color: string;
                    textDecoration: string;
                };
            };
        };
        emphasis: {
            element: string;
            styles: {
                fontStyle: string;
                fontWeight: number;
            };
        };
    };
    /**
      Body
    */
    columbus: {
        standard: {
            element: string;
            styles: {
                fontFeatureSettings: string;
                fontFamily: string;
                fontSize: string;
                lineHeight: number;
                fontWeight: number;
            } | {
                fontFeatureSettings?: undefined;
                fontFamily: string;
                fontSize: string;
                lineHeight: number;
                fontWeight: number;
            };
        };
        'inline-link': {
            element: string;
            styles: {
                color: string;
                display: string;
                '[href]': {
                    textDecoration: string;
                };
                '&:hover': {
                    color: string;
                    textDecoration: string;
                };
            };
        };
        emphasis: {
            element: string;
            styles: {
                fontStyle: string;
                fontWeight: number;
            };
        };
    };
    /**
      Micro
    */
    bates: {
        standard: {
            element: string;
            styles: {
                fontFeatureSettings: string;
                fontFamily: string;
                fontSize: string;
                lineHeight: number;
                letterSpacing: string;
                fontWeight: number;
            } | {
                fontFeatureSettings?: undefined;
                fontFamily: string;
                fontSize: string;
                lineHeight: number;
                letterSpacing: string;
                fontWeight: number;
            };
        };
        'inline-link': {
            element: string;
            styles: {
                color: string;
                display: string;
                '[href]': {
                    textDecoration: string;
                };
                '&:hover': {
                    color: string;
                    textDecoration: string;
                };
            };
        };
        emphasis: {
            element: string;
            styles: {
                fontStyle: string;
                fontWeight: number;
            };
        };
    };
    /**
      ActionText
    */
    amundsen: {
        standard: {
            element: string;
            styles: {
                fontFeatureSettings: string;
                fontFamily: string;
                fontSize: string;
                lineHeight: number;
                letterSpacing: string;
                fontWeight: number;
            } | {
                fontFeatureSettings?: undefined;
                fontFamily: string;
                fontSize: string;
                lineHeight: number;
                letterSpacing: string;
                fontWeight: number;
            };
        };
    };
    /**
      Outliers
    */
    yang: {
        standard: {
            element: string;
            styles: {
                fontWeight: number;
                fontFamily: string;
                fontSize: string;
                lineHeight: number;
                letterSpacing: string;
                fromM: {
                    fontSize: string;
                    lineHeight: number;
                };
            };
        };
    };
    kelly: {
        standard: {
            element: string;
            styles: {
                fontFeatureSettings: string;
                fontFamily: string;
                fontWeight: number;
                fontSize: string;
                lineHeight: number;
            } | {
                fontFeatureSettings?: undefined;
                fontFamily: string;
                fontWeight: number;
                fontSize: string;
                lineHeight: number;
            };
        };
        emphasis: {
            element: string;
            styles: {
                fontStyle: string;
                fontWeight: number;
            };
        };
        'inline-link': {
            element: string;
            styles: {
                color: string;
                display: string;
                '[href]': {
                    textDecoration: string;
                };
                '&:hover': {
                    color: string;
                    textDecoration: string;
                };
            };
        };
    };
    meir: {
        standard: {
            element: string;
            styles: {
                fontFeatureSettings: string;
                fontFamily: string;
                fontWeight: number;
                fontSize: string;
                lineHeight: number;
            } | {
                fontFeatureSettings?: undefined;
                fontFamily: string;
                fontWeight: number;
                fontSize: string;
                lineHeight: number;
            };
        };
    };
};
